#ifndef	_OSFILE_H
#define	_OSFILE_H

#include <cassert>
#include <string>
#include <vector>
#include <cstdlib>

#include <windows.h>

/** Encapsulate a file.
*/
class OsFile
{
	public:
		OsFile( const std::string& strPathname = "" );
		virtual ~OsFile();

		bool SetPathname( const std::string& strPathname );
		inline const std::string& GetPathname() const
			{ return( m_strPathname ); }

		inline bool IsOpen() const
			{ return( m_fd != (FILE*)0 ); }

		bool Open( const std::string& strMode );
		bool Close();
		bool GetSize( __int64& size );

		inline operator FILE*()
			{ return( m_fd ); }

	private:
		// No copy permitted:
		inline OsFile( const OsFile& src ) { }
		inline OsFile& operator=( const OsFile& src ) { return( *this ); }

	protected:
		std::string m_strPathname;
		FILE* m_fd;
};


/** Encapsulate a set of files.
*/
class OsFileVector : public std::vector< OsFile* >
{
	public:
		OsFileVector();
		virtual ~OsFileVector();

		void ClearAll();
		bool PopulateFromRootDirectory( const std::string& strRootDirectory );
		inline const std::string& GetLastRootDirectory() const
			{ return( m_strRootDirectory ); }
		std::string GetRelativePath( const OsFile& osFile, bool convertSeparators = true ) const;

		bool GetSize( __int64& totalSize );

	private:
		// No copy permitted:
		inline OsFileVector( const OsFileVector& src ) { }
		inline OsFileVector& operator=( const OsFileVector& src ) { return( *this ); }

		bool PopulateFromDirectory( const std::string& strDirectory, int level );

		static std::string::value_type cm_dirSep;
		static std::string::value_type cm_dirSepUrl;

	protected:
		std::string m_strRootDirectory;
};

#endif	// !_OSFILE_H
